==> javascriptstuff-db-1.6.0.tgz: package/react-tutorials.js <==
module.exports = {
  "key": "react-tutorials",
  "name": "React Tutorials",
  "description": "Articles that walk you through completing a task with React, step-by-step.",
  "aka": [
    "react walkthroughs",
    "react getting started",
    "react guides"
  ],
  "tags": [
    {
      "name": "redux",
      "description": "The tutorial introduces Redux in combination with React."
    }
  ],
  "articles": [
    {
      "title": "React Tutorial For Beginners",
      "url": "https://ihatetomatoes.net/react-tutorial-for-beginners/",
      "author": "Petr Tichy",
      "date": "2017-09-11",
      "description": "React tutorial for complete beginners. Learn the basic or React.js by following this simple guide for React newbies.",
      "notes": ""
    },
    {
      "title": "Learning React.js: Getting Started and Concepts",
      "url": "https://scotch.io/tutorials/learning-react-getting-started-and-concepts",
      "author": "Ken Wheeler",
      "date": "2017-10-18",
      "description": "The first installment in a new series of tutorials, Learning React, that will focus on becoming proficient and effective with Facebook&'s React library",
      "notes": ""
    },
    {
      "title": "Build with React Tutorial",
      "url": "http://buildwithreact.com/tutorial",
      "author": "buildwithreact",
      "date": "2016-9-13",
      "description": "Learn ReactJS with this simple and interactive tutorial. Topics include JSX, components, events, state, and a quick look under the hood.",
      "notes": ""
    },
    {
      "title": "Raw React",
      "url": "http://jamesknelson.com/learn-raw-react-no-jsx-flux-es6-webpack/",
      "author": "James K Nelson",
      "date": "2016-4-24",
      "description": "Learn React from the ground up, without worrying about JSX, Flux, ES6, Webpack, etc.",
      "notes": ""
    },
    {
      "title": "Official React Tutorial",
      "url": "https://reactjs.org/tutorial/tutorial.html",
      "author": "Facebook",
      "date": "2017-10-27",
      "description": "The React tutorial included in the official React documentation.",
      "notes": ""
    },
    {
      "title": "Comprehensive React.js Guide",
      "url": "http://tylermcginnis.com/reactjs-tutorial-a-comprehensive-guide-to-building-apps-with-react/",
      "author": "Tyler McGinnis",
      "date": "2015-1-12",
      "description": "Guide for learning to build apps with React.",
      "notes": ""
    },
    {
      "title": "Full-Stack Redux Tutorial",
      "url": "http://teropa.info/blog/2015/09/10/full-stack-redux-tutorial.html",
      "author": "Tero Parviainen",
      "date": "2016-2-24",
      "description": "A Comprehensive Guide to Test-First Development with Redux, React, and Immutable",
      "tags": [
        "redux"
      ],
      "notes": ""
    }
  ],
  "projects": []
}

==> javascriptstuff-db-1.10.1.tgz: package/react-tutorials.js <==
module.exports = {
  "key": "react-tutorials",
  "name": "React Tutorials",
  "description": "Articles that walk you through completing a task with React, step-by-step.",
  "aka": [
    "react walkthroughs",
    "react getting started",
    "react guides"
  ],
  "tags": [
    {
      "name": "redux",
      "description": "The tutorial introduces Redux in combination with React."
    }
  ],
  "articles": [
    {
      "title": "React Tutorial For Beginners",
      "url": "https://ihatetomatoes.net/react-tutorial-for-beginners/",
      "author": "Petr Tichy",
      "date": "2017-09-11",
      "description": "React tutorial for complete beginners. Learn the basic or React.js by following this simple guide for React newbies.",
      "notes": ""
    },
    {
      "title": "Learning React.js: Getting Started and Concepts",
      "url": "https://scotch.io/tutorials/learning-react-getting-started-and-concepts",
      "author": "Ken Wheeler",
      "date": "2017-10-18",
      "description": "The first installment in a new series of tutorials, Learning React, that will focus on becoming proficient and effective with Facebook's React library",
      "notes": ""
    },
    {
      "title": "Build with React Tutorial",
      "url": "http://buildwithreact.com/tutorial",
      "author": "buildwithreact",
      "date": "2016-9-13",
      "description": "Learn ReactJS with this simple and interactive tutorial. Topics include JSX, components, events, state, and a quick look under the hood.",
      "notes": ""
    },
    {
      "title": "Raw React",
      "url": "http://jamesknelson.com/learn-raw-react-no-jsx-flux-es6-webpack/",
      "author": "James K Nelson",
      "date": "2016-4-24",
      "description": "Learn React from the ground up, without worrying about JSX, Flux, ES6, Webpack, etc.",
      "notes": ""
    },
    {
      "title": "Official React Tutorial",
      "url": "https://reactjs.org/tutorial/tutorial.html",
      "author": "Facebook",
      "date": "2017-10-27",
      "description": "The React tutorial included in the official React documentation.",
      "notes": ""
    },
    {
      "title": "Comprehensive React.js Guide",
      "url": "http://tylermcginnis.com/reactjs-tutorial-a-comprehensive-guide-to-building-apps-with-react/",
      "author": "Tyler McGinnis",
      "date": "2015-1-12",
      "description": "Guide for learning to build apps with React.",
      "notes": ""
    },
    {
      "title": "Full-Stack Redux Tutorial",
      "url": "http://teropa.info/blog/2015/09/10/full-stack-redux-tutorial.html",
      "author": "Tero Parviainen",
      "date": "2016-2-24",
      "description": "A Comprehensive Guide to Test-First Development with Redux, React, and Immutable",
      "tags": [
        "redux"
      ],
      "notes": ""
    }
  ],
  "projects": []
}
